/*
    Project: TCTEMP
    Version: V1.5
    File   : tc_blowfish.c

    Copyright (c) 2006-2007 Author of TCTEMP. All rights reserved.
    Public Key Fingerprint: 75EB 6BC2 01B7 F6E7 4BD7 CC58 4A5F C393 19EE 6E69

    Covered by TrueCrypt License 2.2 the full text of which is contained
    in the file License.txt included in TCTEMP binary and source code
    distribution archives.

    The copyright notice of this source code file and the public key
    fingerprint must be retained in full.
*/

#include "tc_priv.h"

#ifdef BLOWFISH

int tc_blowfish_ecb_encrypt(const unsigned char *pt, unsigned char *ct, symmetric_key *skey)
{
    int iResult;

    if (pt != ct) {
        memcpy(ct, pt, 8);
    }

    Reverse32(ct);
    Reverse32(ct+4);
    iResult = blowfish_ecb_encrypt(ct, ct, skey);
    Reverse32(ct);
    Reverse32(ct+4);

    return iResult;
}

int tc_blowfish_ecb_decrypt(const unsigned char *ct, unsigned char *pt, symmetric_key *skey)
{
    int iResult;

    if (pt != ct) {
        memcpy(pt, ct, 8);
    }

    Reverse32(pt);
    Reverse32(pt+4);
    iResult = blowfish_ecb_decrypt(pt, pt, skey);
    Reverse32(pt);
    Reverse32(pt+4);

    return iResult;
}

const struct ltc_cipher_descriptor tcblowfish_desc =
{
    "tcblowfish",
    0,
    8, 56, 8, 16,
    &blowfish_setup,
    &tc_blowfish_ecb_encrypt,
    &tc_blowfish_ecb_decrypt,
    &blowfish_test,
    &blowfish_done,
    &blowfish_keysize,
    NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL
};

#endif
